@@ -1,11 +1,10 @@
-# aclint: py3
-from revup.types import RevupUsageException, RevupConflictException
-from revup.revup import main
-
 import asyncio
 import logging
 import sys
 
+from revup.revup import main
+from revup.types import RevupConflictException, RevupUsageException
+
 try:
     # Exit code of 1 is reserved for exception-based exits
     sys.exit(asyncio.run(main()))
